@@ -46,8 +46,14 @@
 #    define IUTEST_OS_WINDOWS_DESKTOP	1
 #  endif
 #elif	defined(__APPLE__)
-#  define IUTEST_OS_MAC					1
-#  define IUTEST_PLATFORM				"Mac OS"
+#  include "TargetConditionals.h"
+#  ifdef TARGET_OS_IPHONE
+#    define IUTEST_OS_IOS				1
+#    define IUTEST_PLATFORM				"iOS"
+#  else
+#    define IUTEST_OS_MAC				1
+#    define IUTEST_PLATFORM				"Mac OS"
+#  endif
 #elif	defined(sun) || defined(__sun)
 #  define IUTEST_OS_SOLARIS				1
 #  define IUTEST_PLATFORM				"Solaris"
@@ -62,6 +68,10 @@
 #  define IUTEST_PLATFORM				"Google Native Client"
 #endif
 
+#if defined(IUTEST_OS_LINUX_ANDROID)
+#  include <android/api-level.h>
+#endif
+
 #if	!defined(IUTEST_HAS_CLOCK) && defined(CLOCKS_PER_SEC)
 #  define IUTEST_HAS_CLOCK			1
 #endif
@@ -91,7 +101,7 @@
 // static_assert
 #if	!defined(IUTEST_HAS_STATIC_ASSERT)
 #  if	defined(__clang__)
-#    if !__has_feature(cxx_static_assert)
+#    if __has_feature(cxx_static_assert)
 #      define IUTEST_HAS_STATIC_ASSERT	1
 #    endif
 #  elif	defined(__GNUC__)
@@ -189,6 +199,12 @@
 #    if defined(__VARIADIC_TEMPLATES) || (__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7) && defined(__GXX_EXPERIMENTAL_CXX0X__))
 #      define IUTEST_HAS_VARIADIC_TEMPLATES	1
 #    endif
+#  elif	defined(_MSC_VER)
+#    if _MSC_FULL_VER == 170051025
+#      define IUTEST_HAS_VARIADIC_TEMPLATES	1
+#      define IUTEST_HAS_VARIADIC_COMBINE	0
+#      define IUTEST_HAS_VARIADIC_VALUES	0
+#    endif
 #  endif
 #endif
 
@@ -205,6 +221,8 @@
 #    if defined(__VARIADIC_TEMPLATES) || (__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7) && (__GNUC_PATCHLEVEL__ >= 1) && defined(__GXX_EXPERIMENTAL_CXX0X__))
 #      define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	1
 #    endif
+#  elif	defined(_MSC_VER)
+#    define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	IUTEST_HAS_VARIADIC_TEMPLATES
 #  endif
 #endif
 
