@@ -19,8 +19,8 @@
 
 //======================================================================
 // include
-#include "iutest_internal_defs.h"
 #include "../iutest_pred.hpp"
+#include "../iutest_package.hpp"
 
 //======================================================================
 // define
@@ -41,7 +41,7 @@
 		protected: virtual void Body(void);													\
 	};																						\
 	::iutest::detail::TestInstance<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>			\
-	s_##testcase_##_##testname_( #testcase_, #testname_										\
+	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_				\
 		, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase);			\
 	void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::Body(void)
 
@@ -58,13 +58,12 @@
 	class IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_) : public parent_class_ {			\
 		IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_));	\
 		public:	IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)(void) {}						\
-		static ::std::string MakeTestName(void) { ::iutest::detail::iuStringStream::type strm; strm << #testname_	\
-		<< "/" << ::iutest::detail::TypeUniqueCounter<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>::count();		\
-			return strm.str(); }																\
+		static ::std::string MakeTestName(void) { return ::iutest::detail::MakeIndexTestName(#testname_		\
+		, ::iutest::detail::GetTypeUniqueCounter<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>()); }		\
 		protected: virtual void Body(void) { method_(__VA_ARGS__); }							\
 	};																							\
 	::iutest::detail::TestInstance<IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)>			\
-	IUTEST_PP_CAT(s_##testcase_##_##testname_, __LINE__)( #testcase_							\
+	IUTEST_PP_CAT(s_##testcase_##_##testname_, __LINE__)( IUTEST_CONCAT_PACKAGE_(testcase_)		\
 	, IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)::MakeTestName().c_str(), #__VA_ARGS__	\
 		, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase)
 
@@ -110,21 +109,13 @@
  * @internal
  * @biref	r؃}N
 */
-#if IUTEST_HAS_RVALUE_REFS
 #define IUTEST_TEST_ASSERT_(expression, on_failure)	\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_					\
-	if( const ::iutest::AssertionResult&& iutest_ar = IUTEST_MAKE_ASSERTIONRESULT_(expression) )	\
+	if( ::iutest::detail::add_revalue_reference<	\
+		const ::iutest::AssertionResult>::type iutest_ar = IUTEST_MAKE_ASSERTIONRESULT_(expression) )	\
 		;											\
 	else											\
 		on_failure(iutest_ar.message())
-#else
-#define IUTEST_TEST_ASSERT_(expression, on_failure)	\
-	IUTEST_AMBIGUOUS_ELSE_BLOCKER_					\
-	if( const ::iutest::AssertionResult iutest_ar = IUTEST_MAKE_ASSERTIONRESULT_(expression) )	\
-		;											\
-	else											\
-		on_failure(iutest_ar.message())
-#endif
 
 #if IUTEST_HAS_EXCEPTIONS
 /**
@@ -135,7 +126,7 @@
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
 	if( const char* msg = "" ) {											\
 		try {																\
-			IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING((void)statement);		\
+			IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING((void)(statement));	\
 			msg = "\nExpected: " #statement " throws an exception of type "	\
 				  #expected_exception ".\n  Actual: it throws nothing.";	\
 			goto IUTEST_PP_CAT(iutest_label_throw, __LINE__);				\
@@ -153,29 +144,38 @@
  * @internal
  * @brief	throw eXgp}N
 */
-#define IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure)	\
-	IUTEST_AMBIGUOUS_ELSE_BLOCKER_													\
-	if( const char* msg = "" ) {													\
-		try {																		\
-			IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING((void)statement);				\
-			msg = "\nExpected: " #statement " throws an exception of type "			\
-				  #expected_exception ".\n  Actual: it throws nothing.";			\
-			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
-		} catch( expected_exception const& e) {										\
-			if( e == expected_exception_value ) {									\
-			} else {																\
-			msg = "\nExpected: " #statement " throws an exception of value "		\
-			#expected_exception_value ".\n  Actual: it throws a different value.";	\
-				goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);				\
-			}																		\
-		} catch( ... ) {															\
-			msg = "\nExpected: " #statement " throws an exception of type "			\
-	          #expected_exception ".\n  Actual: it throws a different type.";		\
-			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
-		}																			\
-	} else																			\
-		IUTEST_PP_CAT(iutest_label_throw_value, __LINE__):							\
-		on_failure(msg)
+#define IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, pred_formatter)	\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_														\
+	if( ::iutest::AssertionResult iutest_ar = ::iutest::AssertionSuccess() ) {			\
+		try {																			\
+			IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING((void)(statement));				\
+			iutest_ar << "\nExpected: " #statement " throws an exception of type "		\
+				#expected_exception ".\n  Actual: it throws nothing.";					\
+			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);						\
+		} catch( expected_exception const& e) {											\
+			if( ::iutest::detail::add_revalue_reference<const ::iutest::AssertionResult>::type 				\
+				ar = pred_formatter("e", #expected_exception_value, e, expected_exception_value) ) {		\
+			} else {																	\
+				iutest_ar << "\nExpected: " #statement " throws an exception of value\n" << ar.message();	\
+				goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
+			}																			\
+		} catch( ... ) {																\
+			iutest_ar << "\nExpected: " #statement " throws an exception of type "		\
+				#expected_exception ".\n  Actual: it throws a different type.";			\
+			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);						\
+		}																				\
+	} else																				\
+		IUTEST_PP_CAT(iutest_label_throw_value, __LINE__):								\
+		on_failure(iutest_ar.message())
+
+#define IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::iutest::internal::EqHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
+#define IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::iutest::internal::NeHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
+#define IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::iutest::internal::CmpHelperSTREQ)
+#define IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::iutest::internal::CmpHelperSTRCASEEQ)
 
 /**
  * @internal
@@ -185,7 +185,7 @@
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
 	if( ::iutest::detail::AlwaysTrue() ) {									\
 		try {																\
-			(void)statement;												\
+			(void)(statement);												\
 			goto IUTEST_PP_CAT(iutest_label_anythrow, __LINE__);			\
 		} catch( ... ) {													\
 		}																	\
@@ -199,21 +199,31 @@
 */
 #define IUTEST_TEST_NO_THROW_(statement, on_failure)						\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
-	if( ::iutest::detail::AlwaysTrue() ) {									\
+	if( ::iutest::AssertionResult iutest_ar = ::iutest::AssertionSuccess() ) {	\
 		try {																\
-			(void)statement;												\
+			(void)(statement);												\
+		} catch( const ::std::exception& e ) {								\
+			iutest_ar << "\nExpected: " #statement " doesn't throw an exception.\n  Actual: it throws. what is \""	\
+				<< e.what() << "\"";										\
+			goto IUTEST_PP_CAT(iutest_label_nothrow, __LINE__);				\
+		} catch( const char *e ) {											\
+			iutest_ar << "\nExpected: " #statement " doesn't throw an exception.\n  Actual: it throws. \""	\
+				<< e << "\"";												\
+			goto IUTEST_PP_CAT(iutest_label_nothrow, __LINE__);				\
 		} catch( ... ) {													\
+			iutest_ar << "\nExpected: " #statement " doesn't throw an exception.\n  Actual: it throws.";	\
 			goto IUTEST_PP_CAT(iutest_label_nothrow, __LINE__);				\
 		}																	\
 	} else																	\
 		IUTEST_PP_CAT(iutest_label_nothrow, __LINE__):						\
-		on_failure("\nExpected: " #statement " doesn't throw an exception.\n  Actual: it throws.")
+		on_failure(iutest_ar.message())
 
 #endif
 
 #define IUTEST_TEST_BOOLEAN_(expression, text, actual, expected, on_failure)	\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_												\
-	if( const ::iutest::AssertionResult iutest_ar = ::iutest::AssertionResult((expression) ? true : false) )	\
+	if( ::iutest::detail::add_revalue_reference<const ::iutest::AssertionResult>::type	\
+		iutest_ar = ::iutest::AssertionResult((expression) ? true : false) )	\
 		;																		\
 	else																		\
 		on_failure(::iutest::internal::GetBooleanAssertionFailureMessage(		\
@@ -249,6 +259,8 @@
 #define	IUTEST_TEST_GE(v1, v2, on_failure)				IUTEST_PRED_FORMAT2_( ::iutest::internal::CmpHelperGE, v1, v2, on_failure )
 #define	IUTEST_TEST_GT(v1, v2, on_failure)				IUTEST_PRED_FORMAT2_( ::iutest::internal::CmpHelperGT, v1, v2, on_failure )
 
+#define IUTEST_TEST_EQ_COLLECTIONS(b1, e1, b2, e2, on_failure) IUTEST_PRED_FORMAT4_( ::iutest::internal::CmpHelperEqCollections, b1, e1, b2, e2, on_failure)
+
 #define IUTEST_TEST_TRUE(expr, text, on_failure)		IUTEST_TEST_BOOLEAN_( expr, text, false, true, on_failure)
 #define IUTEST_TEST_FALSE(expr, text, on_failure)		IUTEST_TEST_BOOLEAN_( !(expr), text, true, false, on_failure)
 
@@ -276,16 +288,20 @@
 		::iutest::detail::NewTestPartResultCheckHelper::Reporter<			\
 			::iutest::detail::NewTestPartResultCheckHelper::CondNe<			\
 			::iutest::TestPartResult::kSuccess> >	iutest_failure_checker;	\
-		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING(statement);				\
+		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING( { (void)0; statement; } )	\
 		if( iutest_failure_checker.count() > 0 ) {							\
 			goto IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__);		\
 		}																	\
 	} else																	\
 		IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__):		\
 		on_failure("\nExpected: " #statement " doesn't generate new failure.\n  Actual: it does.")
-/**
- * @}
-*/
+
+#define IUTEST_TEST_SKIP()		\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_			\
+	if( ::iutest::Test::HasFailure() )		\
+		return;								\
+	else									\
+		return ::iutest::UnitTest::SkipTest()
 
 /**
  * @}
