@@ -69,12 +69,16 @@ static long				xcstol(const wchar_t* src, wchar_t** end, int radix){ return wcst
 */
 inline int iu_stricmp(const char* str1, const char* str2)
 {
-#if		defined(_MSC_VER)
-	return _stricmp(str1, str2);
-#elif	defined(__ARMCC_VERSION) || (defined(IUTEST_OS_LINUX) && !defined(IUTEST_OS_LINUX_ANDROID))
-	return strcasecmp(str1, str2);
-#else
+#if	defined(IUTEST_OS_WINDOWS)
+
+#if	defined(__BORLANDC__)
 	return stricmp(str1, str2);
+#else
+	return _stricmp(str1, str2);
+#endif
+	
+#else
+	return strcasecmp(str1, str2);
 #endif
 }
 
