@@ -46,6 +46,8 @@ namespace iutest
  * @ingroup	TESTDEF
  * @def		IUTEST_TEST(testcase_, testname_)
  * @brief	eXg֐`}N
+ * @param	testcase_	= eXgP[X
+ * @param	testname_	= eXg
 */
 #define IUTEST_TEST(testcase_, testname_)			IUTEST_TEST_(testcase_, testname_, ::iutest::Test	\
 														, ::iutest::internal::GetTestTypeId())
@@ -54,6 +56,8 @@ namespace iutest
  * @ingroup	TESTDEF
  * @def		IUTEST(testcase_, testname_)
  * @brief	eXg֐`}N
+ * @param	testcase_	= eXgP[X
+ * @param	testname_	= eXg
 */
 #define IUTEST(testcase_, testname_)				IUTEST_TEST(testcase_, testname_)
 
@@ -61,6 +65,8 @@ namespace iutest
  * @ingroup	TESTDEF
  * @def		IUTEST_F(testfixture_, testname_)
  * @brief	[U[weXg֐`}N
+ * @param	testfixture_	= eXgtBNX`
+ * @param	testname_		= eXg
 */
 #define IUTEST_F(testfixture_, testname_)			IUTEST_TEST_(testfixture_, testname_, testfixture_	\
 														, ::iutest::internal::GetTypeId< testfixture_ >())
@@ -70,6 +76,9 @@ namespace iutest
  * @ingroup	TESTDEF
  * @def		IUTEST_PMZ(testcase_, testname_, method_, ...)
  * @brief	p^CY֐R[eXg`}N
+ * @param	testcase_	= eXgP[X
+ * @param	testname_	= eXg
+ * @param	method_		= ֐
 */
 #define IUTEST_PMZ(testcase_, testname_, method_, ...)	IIUT_TEST_PMZ_(testcase_, testname_, method_, ::iutest::Test	\
 														, ::iutest::internal::GetTestTypeId(), __VA_ARGS__)
@@ -78,6 +87,9 @@ namespace iutest
  * @ingroup	TESTDEF
  * @def		IUTEST_PMZ_F(testfixture_, testname_, method_, ...)
  * @brief	p^CY֐R[eXg`}N
+ * @param	testfixture_	= eXgtBNX`
+ * @param	testname_		= eXg
+ * @param	method_			= ֐
 */
 #define IUTEST_PMZ_F(testfixture_, testname_, method_, ...)	IIUT_TEST_PMZ_(testfixture_, testname_, method_, testfixture_	\
 														, ::iutest::internal::GetTypeId< testfixture_ >(), __VA_ARGS__)
@@ -87,6 +99,8 @@ namespace iutest
 /**
  * @ingroup	TESTDEF
  * @brief	iutest ̏
+ * @param	argc_	= R}hC̑
+ * @param	argv_	= R}hC
 */
 #define IUTEST_INIT(argc_, argv_)					::iutest::InitIrisUnitTest(argc_, argv_)
 
@@ -105,6 +119,7 @@ namespace iutest
 /**
  * @ingroup		IUTEST_UTIL
  * @brief		XR[ṽeXgbZ[Wւ̃bZ[Wǉ
+ * @param		msg	= bZ[W
 */
 #define IUTEST_SCOPED_TRACE(msg)					IIUT_SCOPED_MESSAGE(msg)
 
@@ -135,6 +150,8 @@ namespace iutest
 /**
  * @ingroup		IUTEST_UTIL
  * @brief		IȎs
+ * @param		file	= t@CpX
+ * @param		line	= sԍ
 */
 #ifndef IUTEST_ADD_FAILURE_AT
 #  define IUTEST_ADD_FAILURE_AT(file, line)			IIUT_ADD_FAILURE_AT(file, line)
@@ -153,6 +170,13 @@ namespace iutest
 #ifndef IUTEST_ASSERT_EQ
 #  define	IUTEST_ASSERT_EQ(expected, actual)		IUTEST_TEST_EQ(expected, actual, IUTEST_ASSERT_FAILURE)
 #endif
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	== eXg(collection)
+*/
+#ifndef IUTEST_ASSERT_EQ_COLLECTIONS
+#  define	IUTEST_ASSERT_EQ_COLLECTIONS(b1, e1, b2, e2)	IUTEST_TEST_EQ_COLLECTIONS(b1, e1, b2, e2, IUTEST_ASSERT_FAILURE)
+#endif
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	!= eXg
@@ -391,6 +415,13 @@ namespace iutest
 #ifndef IUTEST_EXPECT_EQ
 #  define	IUTEST_EXPECT_EQ(expected, actual)		IUTEST_TEST_EQ(expected, actual, IUTEST_EXPECT_FAILURE)
 #endif
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	== eXg(collection)
+*/
+#ifndef IUTEST_EXPECT_EQ_COLLECTIONS
+#  define	IUTEST_EXPECT_EQ_COLLECTIONS(b1, e1, b2, e2)	IUTEST_TEST_EQ_COLLECTIONS(b1, e1, b2, e2, IUTEST_EXPECT_FAILURE)
+#endif
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	!= eXg
@@ -637,6 +668,13 @@ namespace iutest
 #ifndef IUTEST_INFORM_EQ
 #  define	IUTEST_INFORM_EQ(expected, actual)		IUTEST_TEST_EQ(expected, actual, IUTEST_INFORM_FAILURE)
 #endif
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	== eXg(collection)
+*/
+#ifndef IUTEST_INFORM_EQ_COLLECTIONS
+#  define	IUTEST_INFORM_EQ_COLLECTIONS(b1, e1, b2, e2)	IUTEST_TEST_EQ_COLLECTIONS(b1, e1, b2, e2, IUTEST_INFORM_FAILURE)
+#endif
 /**
  * @ingroup	IUTEST_INFORM_
  * @brief	!= eXg
