@@ -21,7 +21,7 @@
 // include
 #include "iutest_result.hpp"
 #include "iutest_printers.hpp"
-#include "internal/iutest_list.h"
+#include "internal/iutest_list.hpp"
 
 namespace iutest_report_result
 {
@@ -270,7 +270,7 @@ inline AssertionResult EqFailure(const char* expected_expression, const char* ac
 	strm << "error: Value of " << actual_expression
 		<< "\n  Actual: " << actual
 		<< "\nExpected: " << expected_expression;
-	if( ignoring_case ) strm << "(ignoring case)";
+	if( ignoring_case ) strm << " (ignoring case)";
 	if( !detail::IsStringEqual(expected_expression, expected) ) strm << "\nWhich is: " << expected;
 	return AssertionFailure() << strm.str();
 }
@@ -351,7 +351,7 @@ inline AssertionResult CmpHelperEQ(const char* expected_str, const char* actual_
 IUTEST_PARGMA_WARN_PUSH()
 IUTEST_PRAGMA_WARN_DISABLE_SIGN_COMPARE()
 
-	if( expected == actual ) return AssertionSuccess();
+	if( actual == expected ) return AssertionSuccess();
 
 	return EqFailure(expected_str, actual_str
 		, FormatForComparisonFailureMessage(expected, actual).c_str()
@@ -397,6 +397,50 @@ public:
 	}
 };
 
+/**
+ * @brief	Equal Collection Helper
+*/
+template<typename T1, typename T2>
+AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperEqCollections(const char* expr1b, const char* expr1e, const char* expr2b, const char* expr2e
+							   , T1 b1, T1 e1, T2 b2, T2 e2)
+{
+	int elem=0;
+	bool result = true;
+	Message ar;
+	for( elem=0; b1 != e1 && b2 != e2; ++b1, ++b2, ++elem )
+	{
+		if( !EqHelper<false>::Compare("", "", *b1, *b2) )
+		{
+			result = false;
+			ar << "\nMismatch in a position " << elem << ": "
+				<< FormatForComparisonFailureMessage(*b1, *b2)
+				<< " vs " << FormatForComparisonFailureMessage(*b2, *b1);
+		}
+	}
+	if( b1 != e1 )
+	{
+		int elem1 = elem;
+		for( ; b1 != e1; ++b1, ++elem1 )
+			;
+		result = false;
+		ar << "\nMismatch element : " << elem1 << " vs " << elem;
+	}
+	if( b2 != e2 )
+	{
+		int elem2 = elem;
+		for( ; b2 != e2; ++b2, ++elem2 )
+			;
+		result = false;
+		ar << "\nMismatch element : " << elem << " vs " << elem2;
+	}
+	if( !result )
+	{
+		return AssertionFailure() << "error: Expected: { " << expr1b << ", " << expr1e << " } == { "
+			<< expr2b << ", " << expr2e << " }\n  Actual:" << ar;
+	}
+	return AssertionSuccess();
+}
+
 /**
  * @brief	Not Equal Helper
  * @tparam	IsNullLiteral	= val1  NULL eǂ
@@ -568,8 +612,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 	{
 		if( strcmp(val1, val2) != 0 ) return AssertionSuccess();
 	}
-	return AssertionFailure() << "error: Value of: " << expr1 << " != " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
 							   , const wchar_t* val1, const wchar_t* val2)
@@ -582,8 +627,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 	{
 		if( wcscmp(val1, val2) != 0 ) return AssertionSuccess();
 	}
-	return AssertionFailure() << "error: Value of: " << expr1 << " != " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
@@ -591,8 +637,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val1 != val2 ) return AssertionSuccess();
-	return AssertionFailure() << "error: Value of: " << expr1 << " == " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
@@ -600,8 +647,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val2 != val1 ) return AssertionSuccess();
-	return AssertionFailure() << "error: Value of: " << expr1 << " == " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
@@ -609,8 +657,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const Elem* val2)
 {
 	if( val1 != val2 ) return AssertionSuccess();
-	return AssertionFailure() << "error: Value of: " << expr1 << " == " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 #if IUTEST_HAS_CHAR16_T
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
@@ -701,8 +750,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 	{
 		if( detail::iu_stricmp(val1, val2) != 0 ) return AssertionSuccess();
 	}
-	return AssertionFailure() << "error: Value of: " << expr1 << " != " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2 << " (ignoring case)"
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
 							   , const wchar_t* val1, const wchar_t* val2)
@@ -715,8 +765,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 	{
 		if( detail::iu_wcsicmp(val1, val2) != 0 ) return AssertionSuccess();
 	}
-	return AssertionFailure() << "error: Value of: " << expr1 << " != " << expr2
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val2, val1) << "\nExpected: " << FormatForComparisonFailureMessage(val1, val2) ;
+	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2 << " (ignoring case)"
+		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
+		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
