@@ -29,10 +29,12 @@ namespace iutest
 /**
  * @brief	eXgP[X
 */
-class TestCase : public detail::iu_list_node<TestCase>
+class TestCase
+	: public detail::iu_list_node<TestCase>
 {
 protected:
 	typedef detail::iu_list<TestInfo>	iuTestInfos;	//!< TestInfo Xg
+	//typedef ::std::vector<TestInfo*>	iuTestInfos;	//!< TestInfo Xg
 protected:
 	/**
 	 * @brief	RXgN^
@@ -61,35 +63,12 @@ public:
 	*/
 	virtual	~TestCase(void) {}
 
-public:
-	/**
-	 * @brief	eXg̎s
-	 * @return	
-	*/
-	bool	Run(void)
-	{
-		if( !should_run() ) return true;
-
-		if( TestFlag::IsEnableFlag(TestFlag::SHUFFLE_TESTS) )
-		{
-			m_testinfos.shuffle(TestEnv::genrand());
-		}
-
-		// eXgJn
-		TestEnv::event_listeners().OnTestCaseStart(*this);
-		bool result = RunImpl();
-		// eXgI
-		TestEnv::event_listeners().OnTestCaseEnd(*this);
-
-		return result;
-	}
-
 public:
 	/** test case ̎擾 */
 	const	char*	name(void)					const	{ return m_testcase_name.c_str(); }
 
 	/** eXg */
-	int				total_test_count(void)		const	{ return m_testinfos.count(); }
+	int				total_test_count(void)		const	{ return m_testinfos.size(); }
 	/** seXg */
 	int				test_to_run_count(void)		const	{ return m_should_run_num; }
 	/** seXg */
@@ -99,7 +78,7 @@ public:
 	/** eXg */
 	int				successful_test_count(void)	const	{ return test_to_run_count() - failed_test_count(); }
 	/** XLbveXg */
-	int				skip_test_count(void)		const	{ return total_test_count() - test_to_run_count(); }
+	int				skip_test_count(void)		const	{ return get_skipped_test_count(); }
 	/** eXg̎s~b */
 	TimeInMillisec	elapsed_time(void)			const	{ return m_elapsedmsec; }
 
@@ -129,35 +108,17 @@ public:
 	}
 
 private:
+	/**
+	 * @brief	eXg̎s
+	 * @return	
+	*/
+	bool	Run(void);
+
 	/**
 	 * @brief	s
 	 * @return	
 	*/
-	bool RunImpl(void)
-	{
-		bool result=true;
-		m_elapsedmsec = 0;
-
-		m_setup();
-		{
-			detail::iuStopWatch sw;
-			sw.start();
-			for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-			{
-				if( it->should_run() )
-				{
-					// s
-					if( !it->Run() )
-					{
-						result = false;
-					}
-				}
-			}
-			m_elapsedmsec = sw.stop();
-		}
-		m_teardown();
-		return result;
-	}
+	bool	RunImpl(void);
 
 public:
 	/**
@@ -182,51 +143,17 @@ private:
 	/**
 	 * @brief	eXg̃NA
 	*/
-	void	clear(void)
-	{
-		for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-		{
-			it->clear();
-		}
-	}
-
+	void	clear(void);
 	/*
 	 * @brief	eXg̃tB^O
 	 * @return	sꍇ͐^
 	*/
-	bool	filter(void)
-	{
-		m_should_run_num = 0;
-		m_disable_num = 0;
-		for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-		{
-			if( m_disable )
-			{
-				// DISABLE ̓`
-				it->m_disable = true;
-			}
-			if( it->is_disabled_test() )
-			{
-				++m_disable_num;
-			}
-			if( it->filter() )
-			{
-				++m_should_run_num;
-			}
-		}
-		return should_run();
-	}
+	bool	filter(void);
 
 	/** seXg */
-	int get_failed_test_count(void) const
-	{
-		int count = 0;
-		for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-		{
-			if( it->should_run() && it->HasFailure() ) ++count;
-		}
-		return count;
-	}
+	int get_failed_test_count(void) const;
+	/** XLbveXg */
+	int get_skipped_test_count(void) const;
 
 private:
 	friend bool	operator == (const TestCase& lhs, const TestCase& rhs)
@@ -237,9 +164,9 @@ private:
 	void	push_back(TestInfo* p)	{ m_testinfos.push_back(p); }
 
 private:
-	iuTestInfos::iterator	begin(void)	const		{ return m_testinfos.begin(); }
-	iuTestInfos::iterator	end(void)	const		{ return m_testinfos.end(); }
-	TestTypeId				get_typeid(void) const	{ return m_id; }
+	iuTestInfos::const_iterator	begin(void)	const		{ return m_testinfos.begin(); }
+	iuTestInfos::const_iterator	end(void)	const		{ return m_testinfos.end(); }
+	TestTypeId					get_typeid(void) const	{ return m_id; }
 
 private:
 	friend class UnitTestImpl;
@@ -277,9 +204,7 @@ protected:
 	*/
 	TypedTestCase(const char* testcase_name, TestTypeId id, SetUpMethod setup, TearDownMethod teardown)
 		: TestCase(testcase_name, id, setup, teardown)
-#if IUTEST_HAS_RTTI
 		, m_type_param(detail::GetTypeName<TypeParam>())
-#endif
 	{}
 
 public:
@@ -309,6 +234,101 @@ public:
 
 }	// end of namespace detail
 
+inline bool	TestCase::Run(void)
+{
+	if( !should_run() ) return true;
+
+	if( TestFlag::IsEnableFlag(TestFlag::SHUFFLE_TESTS) )
+	{
+		RandomShuffle(m_testinfos, TestEnv::genrand());
+	}
+
+	// eXgJn
+	TestEnv::event_listeners().OnTestCaseStart(*this);
+	bool result = RunImpl();
+	// eXgI
+	TestEnv::event_listeners().OnTestCaseEnd(*this);
+
+	return result;
+}
+
+inline bool TestCase::RunImpl(void)
+{
+	bool result=true;
+	m_elapsedmsec = 0;
+
+	m_setup();
+	{
+		detail::iuStopWatch sw;
+		sw.start();
+		for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
+		{
+			if( (*it)->should_run() )
+			{
+				// s
+				if( !(*it)->Run() )
+				{
+					result = false;
+				}
+			}
+		}
+		m_elapsedmsec = sw.stop();
+	}
+	m_teardown();
+	return result;
+}
+
+inline void	TestCase::clear(void)
+{
+	for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
+	{
+		(*it)->clear();
+	}
+}
+
+inline bool	TestCase::filter(void)
+{
+	m_should_run_num = 0;
+	m_disable_num = 0;
+	for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
+	{
+		if( m_disable )
+		{
+			// DISABLE ̓`
+			(*it)->m_disable = true;
+		}
+		if( (*it)->is_disabled_test() )
+		{
+			++m_disable_num;
+		}
+		if( (*it)->filter() )
+		{
+			++m_should_run_num;
+		}
+	}
+	return should_run();
+}
+
+inline int TestCase::get_failed_test_count(void) const
+{
+	int count = 0;
+	for( iuTestInfos::const_iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
+	{
+		if( (*it)->should_run() && (*it)->HasFailure() ) ++count;
+	}
+	return count;
+}
+
+inline int TestCase::get_skipped_test_count(void) const
+{
+	int count = 0;
+	for( iuTestInfos::const_iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
+	{
+		if( (*it)->is_skipped() ) ++count;
+	}
+	return count;
+}
+
 }	// end of namespace iutest
 
 #endif
