@@ -25,6 +25,37 @@ namespace iuutil
 //======================================================================
 // function
 
+/**
+ * @brief	CfbNXeXg擾
+*/
+inline ::std::string TestNameRemoveIndexName(const char* name)
+{
+	const char* const p = strrchr(name, '/');
+	if( p == NULL ) return name;
+	return ::std::string(name, p);
+}
+
+/**
+ * @brief	CfbNXeXgP[X擾
+*/
+inline ::std::string TestCaseNameRemoveIndexName(const char* name)
+{
+	return TestNameRemoveIndexName(name);
+}
+
+/**
+ * @brief	CX^XƃCfbNXeXgP[X擾
+*/
+inline ::std::string TestCaseNameRemoveInstantiateAndIndexName(const char* name)
+{
+	// 擪ɃCX^X
+	const char* const p1 = strchr(name, '/');
+	if( p1 == NULL ) return name;
+	const char* const p2 = strrchr(p1+1, '/');
+	if( p2 == NULL ) return p1+1;
+	return ::std::string(p1+1, p2);
+}
+
 /**
  * @brief	TestCase ̌
 */
