@@ -27,6 +27,7 @@ class FooEnvironment : public ::iutest::Environment
 		iuutil::Console::output("FooEnvironment::TearDown\n");
 	}
 };
+#include <iostream>
 
 #ifdef UNICODE
 int wmain(int argc, wchar_t* argv[])
@@ -82,6 +83,17 @@ IUTEST(Test, Stream)
 	IUTEST_SUCCEED() << L"OK!!";
 }
 
+/** --------------------------------------------------
+ * pbP[W
+*//*--------------------------------------------------*/
+IUTEST_PACKAGE(TestPackage)
+{
+	IUTEST(Test, Version)
+	{
+		IUTEST_ASSERT_TRUE(true);
+	}
+}
+
 /** --------------------------------------------------
  * eXgtBNX`̗p
 *//*--------------------------------------------------*/
@@ -169,6 +181,12 @@ IUTEST(AssertionTest, Base)
 		::std::vector<int> v1, v2;
 		IUTEST_EXPECT_EQ(v1, v2);
 	}
+	// EQ_COLLECTIONS
+	{
+		int a[] = { 0, 1, 2, 3 };
+		int b[] = { 0, 1, 2, 3 };
+		IUTEST_ASSERT_EQ_COLLECTIONS(a, a+4, b, b+4);
+	}
 
 	// NE
 	{
@@ -633,6 +651,7 @@ IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 2, 2);
 
 #endif
 
+
 /** --------------------------------------------------
  * s̊mF
 *//*--------------------------------------------------*/
@@ -734,6 +753,7 @@ IUTEST(TestExpectFailure, Exception)
 	IUTEST_EXPECT_THROW(ExceptionFunction(0), int);
 	IUTEST_EXPECT_ANY_THROW(ExceptionFunction(0));
 	IUTEST_EXPECT_NO_THROW(ExceptionFunction(2));
+	IUTEST_EXPECT_NO_THROW(throw "error");
 
 	IUTEST_EXPECT_THROW_VALUE_EQ(ExceptionFunction(1), int, 0);
 	IUTEST_EXPECT_THROW_VALUE_NE(ExceptionFunction(1), int, 2);
@@ -772,6 +792,24 @@ IUTEST(TestExpectFailure, Mix)
 	IUTEST_EXPECT_DOUBLE_EQ(0.0, 0.1);
 	IUTEST_EXPECT_NEAR(0, 100, 2);
 	IUTEST_EXPECT_FAIL();
+	{
+		::std::string str1 = "test";
+		::std::string str2 = "text";
+
+		IUTEST_EXPECT_STREQ("text", str1);
+		IUTEST_EXPECT_STRNE("text", str2);
+		IUTEST_EXPECT_STRCASEEQ("Text", str1);
+		IUTEST_EXPECT_STRCASENE("Text", str2);
+	}
+	// EQ_COLLECTIONS
+	{
+		int  aa[] = { 0, 1, 2, 3, 4 };
+		int  ab[] = { 0, 1, 2, 3, 4, 5 };
+		char ac[] = { 0, 0, 2, 3, 5 };
+		IUTEST_EXPECT_EQ_COLLECTIONS(aa, aa+(sizeof(aa)/sizeof(aa[0])), ab, ab+(sizeof(ab)/sizeof(ab[0])));
+		IUTEST_EXPECT_EQ_COLLECTIONS(ab, ab+(sizeof(ab)/sizeof(ab[0])), aa, aa+(sizeof(aa)/sizeof(aa[0])));
+		IUTEST_EXPECT_EQ_COLLECTIONS(aa, aa+(sizeof(aa)/sizeof(aa[0])), ac, ac+(sizeof(ac)/sizeof(ac[0])));
+	}
 }
 
 // Tu[`
