@@ -13,6 +13,10 @@
 #  include "../include/listener/iutest_tap_printer.hpp"
 #endif
 
+#ifdef USE_PROGRESS
+#  include "../include/listener/iutest_progress_printer.hpp"
+#endif
+
 #ifdef UNICODE
 int wmain(int argc, wchar_t* argv[])
 #else
@@ -22,9 +26,11 @@ int main(int argc, char* argv[])
 	IUTEST_INIT(&argc, argv);
 
 #ifdef USE_TAP
-	iutest::TestEventListeners& listeners = iutest::UnitTest::GetInstance()->listeners();
-	delete listeners.Release(listeners.default_result_printer());
-	listeners.Append( new iutest::TAPPrintListener );
+	::iutest::SetUpTAPPrintListener();
+#endif
+
+#ifdef USE_PROGRESS
+	::iutest::SetUpProgressPrintListener();
 #endif
 	
 	return IUTEST_RUN_ALL_TESTS();	// run all
